==> zio-aws-robomaker_2.12-6.20.61.1-sources.jar: zio/aws/robomaker/model/WorldExportJobSummary.scala <==
package zio.aws.robomaker.model
import zio.aws.robomaker.model.primitives.{CreatedAt, Arn}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class WorldExportJobSummary(
    arn: Optional[Arn] = Optional.Absent,
    status: Optional[zio.aws.robomaker.model.WorldExportJobStatus] =
      Optional.Absent,
    createdAt: Optional[CreatedAt] = Optional.Absent,
    worlds: Optional[Iterable[Arn]] = Optional.Absent,
    outputLocation: Optional[zio.aws.robomaker.model.OutputLocation] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary = {
    import WorldExportJobSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary
      .builder()
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(createdAt.map(value => CreatedAt.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(
        worlds.map(value =>
          value.map { item =>
            Arn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.worlds)
      .optionallyWith(outputLocation.map(value => value.buildAwsValue()))(
        _.outputLocation
      )
      .build()
  }
  def asReadOnly: zio.aws.robomaker.model.WorldExportJobSummary.ReadOnly =
    zio.aws.robomaker.model.WorldExportJobSummary.wrap(buildAwsValue())
}
object WorldExportJobSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.WorldExportJobSummary =
      zio.aws.robomaker.model.WorldExportJobSummary(
        arn.map(value => value),
        status.map(value => value),
        createdAt.map(value => value),
        worlds.map(value => value),
        outputLocation.map(value => value.asEditable)
      )
    def arn: Optional[Arn]
    def status: Optional[zio.aws.robomaker.model.WorldExportJobStatus]
    def createdAt: Optional[CreatedAt]
    def worlds: Optional[List[Arn]]
    def outputLocation
        : Optional[zio.aws.robomaker.model.OutputLocation.ReadOnly]
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.robomaker.model.WorldExportJobStatus] =
      AwsError.unwrapOptionField("status", status)
    def getCreatedAt: ZIO[Any, AwsError, CreatedAt] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getWorlds: ZIO[Any, AwsError, List[Arn]] =
      AwsError.unwrapOptionField("worlds", worlds)
    def getOutputLocation
        : ZIO[Any, AwsError, zio.aws.robomaker.model.OutputLocation.ReadOnly] =
      AwsError.unwrapOptionField("outputLocation", outputLocation)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary
  ) extends zio.aws.robomaker.model.WorldExportJobSummary.ReadOnly {
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.robomaker.model.primitives.Arn(value))
    override val status
        : Optional[zio.aws.robomaker.model.WorldExportJobStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.robomaker.model.WorldExportJobStatus.wrap(value))
    override val createdAt: Optional[CreatedAt] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.robomaker.model.primitives.CreatedAt(value))
    override val worlds: Optional[List[Arn]] = zio.aws.core.internal
      .optionalFromNullable(impl.worlds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.robomaker.model.primitives.Arn(item)
        }.toList
      )
    override val outputLocation
        : Optional[zio.aws.robomaker.model.OutputLocation.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.outputLocation())
        .map(value => zio.aws.robomaker.model.OutputLocation.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary
  ): zio.aws.robomaker.model.WorldExportJobSummary.ReadOnly = new Wrapper(impl)
}

==> zio-aws-robomaker_2.13-5.17.149.1-sources.jar: zio/aws/robomaker/model/WorldExportJobSummary.scala <==
package zio.aws.robomaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.robomaker.model.primitives.{CreatedAt, Arn}
import scala.jdk.CollectionConverters._
final case class WorldExportJobSummary(
    arn: Option[Arn] = None,
    status: Option[zio.aws.robomaker.model.WorldExportJobStatus] = None,
    createdAt: Option[CreatedAt] = None,
    worlds: Option[Iterable[Arn]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary = {
    import WorldExportJobSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary
      .builder()
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(createdAt.map(value => CreatedAt.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(
        worlds.map(value =>
          value.map { item =>
            Arn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.worlds)
      .build()
  }
  def asReadOnly: zio.aws.robomaker.model.WorldExportJobSummary.ReadOnly =
    zio.aws.robomaker.model.WorldExportJobSummary.wrap(buildAwsValue())
}
object WorldExportJobSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.WorldExportJobSummary =
      zio.aws.robomaker.model.WorldExportJobSummary(
        arn.map(value => value),
        status.map(value => value),
        createdAt.map(value => value),
        worlds.map(value => value)
      )
    def arn: Option[Arn]
    def status: Option[zio.aws.robomaker.model.WorldExportJobStatus]
    def createdAt: Option[CreatedAt]
    def worlds: Option[List[Arn]]
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.robomaker.model.WorldExportJobStatus] =
      AwsError.unwrapOptionField("status", status)
    def getCreatedAt: ZIO[Any, AwsError, CreatedAt] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getWorlds: ZIO[Any, AwsError, List[Arn]] =
      AwsError.unwrapOptionField("worlds", worlds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary
  ) extends zio.aws.robomaker.model.WorldExportJobSummary.ReadOnly {
    override val arn: Option[Arn] = scala
      .Option(impl.arn())
      .map(value => zio.aws.robomaker.model.primitives.Arn(value))
    override val status: Option[zio.aws.robomaker.model.WorldExportJobStatus] =
      scala
        .Option(impl.status())
        .map(value => zio.aws.robomaker.model.WorldExportJobStatus.wrap(value))
    override val createdAt: Option[CreatedAt] = scala
      .Option(impl.createdAt())
      .map(value => zio.aws.robomaker.model.primitives.CreatedAt(value))
    override val worlds: Option[List[Arn]] = scala
      .Option(impl.worlds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.robomaker.model.primitives.Arn(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.WorldExportJobSummary
  ): zio.aws.robomaker.model.WorldExportJobSummary.ReadOnly = new Wrapper(impl)
}
